@@ -38,7 +38,6 @@
 #include "ephy-history.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
-#include "ephy-stock-icons.h"
 #include "ephy-string.h"
 #include "ephy-web-view.h"
 #include "nautilus-floating-bar.h"
@@ -56,6 +55,8 @@ static gboolean ephy_embed_inspect_close_cb (WebKitWebInspector *inspector,
 
 #define EPHY_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED, EphyEmbedPrivate))
 
+#define EPHY_EMBED_STATUSBAR_TAB_MESSAGE_CONTEXT_DESCRIPTION "tab_message"
+
 typedef struct {
   gchar *text;
   guint context_id;
@@ -90,10 +91,141 @@ struct _EphyEmbedPrivate
   guint clear_progress_source_id;
 
   gulong status_handler_id;
+  gulong progress_update_handler_id;
 };
 
 G_DEFINE_TYPE (EphyEmbed, ephy_embed, GTK_TYPE_BOX)
 
+/* Portions of the following code based on GTK+.
+ * License block as follows:
+ *
+ * GTK - The GIMP Toolkit
+ * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+ * GtkStatusbar Copyright (C) 1998 Shawn T. Amundson
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ *
+ * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
+ * file for a list of people on the GTK+ Team.  See the ChangeLog
+ * files for a list of changes.  These files are distributed with
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
+ *
+ */
+
+static guint
+ephy_embed_statusbar_get_context_id (EphyEmbed *embed, const char  *context_description)
+{
+  char *string;
+  guint id;
+
+  g_return_val_if_fail (EPHY_IS_EMBED (embed), 0);
+  g_return_val_if_fail (context_description != NULL, 0);
+
+  /* we need to preserve namespaces on object datas */
+  string = g_strconcat ("ephy-embed-status-bar-context:", context_description, NULL);
+
+  id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (embed), string));
+  if (id == 0) {
+    EphyEmbedPrivate *priv = embed->priv;
+
+    id = priv->seq_context_id++;
+    g_object_set_data_full (G_OBJECT (embed), string, GUINT_TO_POINTER (id), NULL);
+    priv->keys = g_slist_prepend (priv->keys, string);
+  } else
+    g_free (string);
+
+  return id;
+}
+
+static void
+ephy_embed_set_statusbar_label (EphyEmbed *embed, const char *label)
+{
+  EphyEmbedPrivate *priv = embed->priv;
+
+  nautilus_floating_bar_set_label (NAUTILUS_FLOATING_BAR (priv->floating_bar), label);
+
+  if (label == NULL || label[0] == '\0') {
+    gtk_widget_hide (priv->floating_bar);
+    gtk_widget_set_halign (priv->floating_bar, GTK_ALIGN_START);
+  } else
+    gtk_widget_show (priv->floating_bar);
+}
+
+static void
+ephy_embed_statusbar_update (EphyEmbed *embed, const char *text)
+{
+  g_return_if_fail (EPHY_IS_EMBED (embed));
+
+  ephy_embed_set_statusbar_label (embed, text);
+}
+
+static guint
+ephy_embed_statusbar_push (EphyEmbed *embed, guint context_id, const char *text)
+{
+  EphyEmbedPrivate *priv;
+  EphyEmbedStatusbarMsg *msg;
+
+  g_return_val_if_fail (EPHY_IS_EMBED (embed), 0);
+  g_return_val_if_fail (context_id != 0, 0);
+  g_return_val_if_fail (text != NULL, 0);
+
+  priv = embed->priv;
+
+  msg = g_slice_new (EphyEmbedStatusbarMsg);
+  msg->text = g_strdup (text);
+  msg->context_id = context_id;
+  msg->message_id = priv->seq_message_id++;
+
+  priv->messages = g_slist_prepend (priv->messages, msg);
+
+  ephy_embed_statusbar_update (embed, text);
+
+  return msg->message_id;
+}
+
+/* End of code based on GTK+ GtkStatusbar. */
+
+static void
+ephy_embed_statusbar_pop (EphyEmbed *embed, guint context_id)
+{
+  EphyEmbedPrivate *priv;
+  EphyEmbedStatusbarMsg *msg;
+  GSList *list;
+
+  g_return_if_fail (EPHY_IS_EMBED (embed));
+  g_return_if_fail (context_id != 0);
+
+  priv = embed->priv;
+
+  for (list = priv->messages; list; list = list->next) {
+    EphyEmbedStatusbarMsg *msg = list->data;
+
+    if (msg->context_id == context_id) {
+      priv->messages = g_slist_remove_link (priv->messages, list);
+      g_free (msg->text);
+      g_slice_free (EphyEmbedStatusbarMsg, msg);
+      g_slist_free_1 (list);
+      break;
+    }
+  }
+
+  msg = priv->messages ? priv->messages->data : NULL;
+  ephy_embed_statusbar_update (embed, msg ? msg->text : NULL);
+}
+
 static void
 restore_zoom_level (EphyEmbed *embed,
                     const char *address)
@@ -255,7 +387,7 @@ ephy_embed_dispose (GObject *object)
   EphyEmbed *embed = EPHY_EMBED (object);
   EphyEmbedPrivate *priv = embed->priv;
 
-  if (embed->priv->inspector_window) {
+  if (priv->inspector_window) {
     WebKitWebInspector *inspector;
 
     inspector = webkit_web_view_get_inspector (priv->web_view);
@@ -277,13 +409,23 @@ ephy_embed_dispose (GObject *object)
     priv->pop_statusbar_later_source_id = 0;
   }
 
+  if (priv->clear_progress_source_id) {
+    g_source_remove (priv->clear_progress_source_id);
+    priv->clear_progress_source_id = 0;
+  }
+
   /* Do not listen to status message notifications anymore, if we try
    * to update the statusbar after dispose we might crash. */
   if (priv->status_handler_id) {
-    g_signal_handler_disconnect (priv->web_view, embed->priv->status_handler_id);
+    g_signal_handler_disconnect (priv->web_view, priv->status_handler_id);
     priv->status_handler_id = 0;
   }
 
+  if (priv->progress_update_handler_id) {
+    g_signal_handler_disconnect (priv->web_view, priv->progress_update_handler_id);
+    priv->progress_update_handler_id = 0;
+  }
+
   G_OBJECT_CLASS (ephy_embed_parent_class)->dispose (object);
 }
 
@@ -291,20 +433,21 @@ static void
 ephy_embed_finalize (GObject *object)
 {
   EphyEmbed *embed = EPHY_EMBED (object);
+  EphyEmbedPrivate *priv = embed->priv;
   GSList *list;
 
-  list = embed->priv->destroy_on_transition_list;
+  list = priv->destroy_on_transition_list;
   for (; list; list = list->next) {
     GtkWidget *widget = GTK_WIDGET (list->data);
     g_signal_handlers_disconnect_by_func (widget, remove_from_destroy_list_cb, embed);
   }
-  g_slist_free (embed->priv->destroy_on_transition_list);
+  g_slist_free (priv->destroy_on_transition_list);
 
-  g_signal_handlers_disconnect_by_func (embed->priv->history,
+  g_signal_handlers_disconnect_by_func (priv->history,
                                         ephy_embed_history_cleared_cb,
                                         embed);
 
-  for (list = embed->priv->messages; list; list = list->next) {
+  for (list = priv->messages; list; list = list->next) {
     EphyEmbedStatusbarMsg *msg;
 
     msg = list->data;
@@ -312,17 +455,14 @@ ephy_embed_finalize (GObject *object)
     g_slice_free (EphyEmbedStatusbarMsg, msg);
   }
 
-  g_slist_free (embed->priv->messages);
-  embed->priv->messages = NULL;
+  g_slist_free (priv->messages);
+  priv->messages = NULL;
 
-  for (list = embed->priv->keys; list; list = list->next)
+  for (list = priv->keys; list; list = list->next)
     g_free (list->data);
 
-  g_slist_free (embed->priv->keys);
-  embed->priv->keys = NULL;
-
-  if (embed->priv->clear_progress_source_id)
-    g_source_remove (embed->priv->clear_progress_source_id);
+  g_slist_free (priv->keys);
+  priv->keys = NULL;
 
   G_OBJECT_CLASS (ephy_embed_parent_class)->finalize (object);
 }
@@ -439,20 +579,6 @@ download_requested_cb (WebKitWebView *web_view,
   return TRUE;
 }
 
-void
-_ephy_embed_set_statusbar_label (EphyEmbed *embed, const char *label)
-{
-  EphyEmbedPrivate *priv = embed->priv;
-
-  nautilus_floating_bar_set_label (NAUTILUS_FLOATING_BAR (priv->floating_bar), label);
-
-  if (label == NULL || label[0] == '\0') {
-    gtk_widget_hide (priv->floating_bar);
-    gtk_widget_set_halign (priv->floating_bar, GTK_ALIGN_START);
-  } else
-    gtk_widget_show (priv->floating_bar);
-}
-
 static gboolean
 pop_statusbar_later_cb (gpointer data)
 {
@@ -550,7 +676,7 @@ progress_update (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed)
 
   if (progress == 1.0 || !loading)
     priv->clear_progress_source_id = g_timeout_add (500,
-                                                    (GSourceFunc) clear_progress_cb,
+                                                    (GSourceFunc)clear_progress_cb,
                                                     embed);
   else
     gtk_widget_show (priv->progress);
@@ -573,7 +699,7 @@ ephy_embed_constructed (GObject *object)
 
   /* Skeleton */
   web_view = WEBKIT_WEB_VIEW (ephy_web_view_new ());
-  scrolled_window = GTK_WIDGET (embed->priv->scrolled_window);
+  scrolled_window = GTK_WIDGET (priv->scrolled_window);
   overlay = gtk_overlay_new ();
   gtk_widget_add_events (overlay, 
                          GDK_ENTER_NOTIFY_MASK |
@@ -589,17 +715,17 @@ ephy_embed_constructed (GObject *object)
 
   gtk_overlay_add_overlay (GTK_OVERLAY (overlay), priv->floating_bar);
 
-  embed->priv->progress = gtk_progress_bar_new ();
-  gtk_widget_set_name (embed->priv->progress, "ephy-progress-bar");
-  gtk_widget_set_halign (embed->priv->progress, GTK_ALIGN_FILL);
-  gtk_widget_set_valign (embed->priv->progress, GTK_ALIGN_START);
-  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), embed->priv->progress);
+  priv->progress = gtk_progress_bar_new ();
+  gtk_widget_set_name (priv->progress, "ephy-progress-bar");
+  gtk_widget_set_halign (priv->progress, GTK_ALIGN_FILL);
+  gtk_widget_set_valign (priv->progress, GTK_ALIGN_START);
+  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), priv->progress);
 
-  paned = GTK_WIDGET (embed->priv->paned);
+  paned = GTK_WIDGET (priv->paned);
 
-  embed->priv->web_view = web_view;
-  g_signal_connect (web_view, "notify::progress",
-                    G_CALLBACK (progress_update), object);
+  priv->web_view = web_view;
+  priv->progress_update_handler_id =  g_signal_connect (web_view, "notify::progress",
+                                                        G_CALLBACK (progress_update), object);
 
   gtk_container_add (GTK_CONTAINER (scrolled_window),
                      GTK_WIDGET (web_view));
@@ -607,11 +733,11 @@ ephy_embed_constructed (GObject *object)
                    TRUE, FALSE);
 
   gtk_box_pack_start (GTK_BOX (embed),
-                      GTK_WIDGET (embed->priv->top_widgets_vbox),
+                      GTK_WIDGET (priv->top_widgets_vbox),
                       FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (embed), paned, TRUE, TRUE, 0);
 
-  gtk_widget_show (GTK_WIDGET (embed->priv->top_widgets_vbox));
+  gtk_widget_show (GTK_WIDGET (priv->top_widgets_vbox));
   gtk_widget_show (GTK_WIDGET (web_view));
   gtk_widget_show_all (paned);
 
@@ -622,9 +748,9 @@ ephy_embed_constructed (GObject *object)
                     "signal::notify::zoom-level", G_CALLBACK (zoom_changed_cb), embed,
                     NULL);
 
-  embed->priv->status_handler_id = g_signal_connect (web_view, "notify::status-message",
-                                                     G_CALLBACK (status_message_notify_cb),
-                                                     embed);
+  priv->status_handler_id = g_signal_connect (web_view, "notify::status-message",
+                                              G_CALLBACK (status_message_notify_cb),
+                                              embed);
 
   /* Window features */
   window_features = webkit_web_view_get_window_features (web_view);
@@ -636,24 +762,24 @@ ephy_embed_constructed (GObject *object)
                     NULL);
 
   /* The inspector */
-  embed->priv->inspector_web_view  = ephy_web_view_new ();
-  embed->priv->inspector_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  priv->inspector_web_view  = ephy_web_view_new ();
+  priv->inspector_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   inspector = webkit_web_view_get_inspector (web_view);
 
-  embed->priv->inspector_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (embed->priv->inspector_scrolled_window),
+  priv->inspector_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->inspector_scrolled_window),
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_container_add (GTK_CONTAINER (embed->priv->inspector_window),
-                     embed->priv->inspector_scrolled_window);
-  gtk_container_add (GTK_CONTAINER (embed->priv->inspector_scrolled_window),
-                     embed->priv->inspector_web_view);
+  gtk_container_add (GTK_CONTAINER (priv->inspector_window),
+                     priv->inspector_scrolled_window);
+  gtk_container_add (GTK_CONTAINER (priv->inspector_scrolled_window),
+                     priv->inspector_web_view);
 
-  gtk_window_set_title (GTK_WINDOW (embed->priv->inspector_window),
+  gtk_window_set_title (GTK_WINDOW (priv->inspector_window),
                         _("Web Inspector"));
-  gtk_window_set_default_size (GTK_WINDOW (embed->priv->inspector_window),
+  gtk_window_set_default_size (GTK_WINDOW (priv->inspector_window),
                                800, 600);
 
-  g_signal_connect (embed->priv->inspector_window,
+  g_signal_connect (priv->inspector_window,
                     "delete-event", G_CALLBACK (gtk_widget_hide_on_delete),
                     NULL);
 
@@ -672,9 +798,9 @@ ephy_embed_constructed (GObject *object)
 
   ephy_embed_prefs_add_embed (embed);
 
-  embed->priv->history = EPHY_HISTORY (ephy_embed_shell_get_global_history (ephy_embed_shell_get_default ()));
+  priv->history = EPHY_HISTORY (ephy_embed_shell_get_global_history (ephy_embed_shell_get_default ()));
 
-  g_signal_connect (embed->priv->history,
+  g_signal_connect (priv->history,
                     "cleared", G_CALLBACK (ephy_embed_history_cleared_cb),
                     embed);
 }
@@ -765,117 +891,3 @@ ephy_embed_remove_top_widget (EphyEmbed *embed, GtkWidget *widget)
   gtk_container_remove (GTK_CONTAINER (embed->priv->top_widgets_vbox),
                         GTK_WIDGET (widget));
 }
-
-static void
-ephy_embed_statusbar_update (EphyEmbed *embed, const char *text)
-{
-  g_return_if_fail (EPHY_IS_EMBED (embed));
-
-  _ephy_embed_set_statusbar_label (embed, text);
-}
-
-/* Portions of the following code based on GTK+.
- * License block as follows:
- *
- * GTK - The GIMP Toolkit
- * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
- * GtkStatusbar Copyright (C) 1998 Shawn T. Amundson
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
- * file for a list of people on the GTK+ Team.  See the ChangeLog
- * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
- *
- */
-
-guint
-ephy_embed_statusbar_get_context_id (EphyEmbed *embed, const char  *context_description)
-{
-  char *string;
-  guint id;
-
-  g_return_val_if_fail (EPHY_IS_EMBED (embed), 0);
-  g_return_val_if_fail (context_description != NULL, 0);
-
-  /* we need to preserve namespaces on object datas */
-  string = g_strconcat ("ephy-embed-status-bar-context:", context_description, NULL);
-
-  id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (embed), string));
-  if (id == 0) {
-    EphyEmbedPrivate *priv = embed->priv;
-
-    id = priv->seq_context_id++;
-    g_object_set_data_full (G_OBJECT (embed), string, GUINT_TO_POINTER (id), NULL);
-    priv->keys = g_slist_prepend (priv->keys, string);
-  } else
-    g_free (string);
-
-  return id;
-}
-
-guint
-ephy_embed_statusbar_push (EphyEmbed *embed, guint context_id, const char *text)
-{
-  EphyEmbedPrivate *priv;
-  EphyEmbedStatusbarMsg *msg;
-
-  g_return_val_if_fail (EPHY_IS_EMBED (embed), 0);
-  g_return_val_if_fail (context_id != 0, 0);
-  g_return_val_if_fail (text != NULL, 0);
-
-  priv = embed->priv;
-
-  msg = g_slice_new (EphyEmbedStatusbarMsg);
-  msg->text = g_strdup (text);
-  msg->context_id = context_id;
-  msg->message_id = priv->seq_message_id++;
-
-  priv->messages = g_slist_prepend (priv->messages, msg);
-
-  ephy_embed_statusbar_update (embed, text);
-
-  return msg->message_id;
-}
-
-void
-ephy_embed_statusbar_pop (EphyEmbed *embed, guint context_id)
-{
-  EphyEmbedPrivate *priv;
-  EphyEmbedStatusbarMsg *msg;
-  GSList *list;
-
-  g_return_if_fail (EPHY_IS_EMBED (embed));
-  g_return_if_fail (context_id != 0);
-
-  priv = embed->priv;
-
-  for (list = priv->messages; list; list = list->next) {
-    EphyEmbedStatusbarMsg *msg = list->data;
-
-    if (msg->context_id == context_id) {
-      priv->messages = g_slist_remove_link (priv->messages, list);
-      g_free (msg->text);
-      g_slice_free (EphyEmbedStatusbarMsg, msg);
-      g_slist_free_1 (list);
-      break;
-    }
-  }
-
-  msg = priv->messages ? priv->messages->data : NULL;
-  ephy_embed_statusbar_update (embed, msg ? msg->text : NULL);
-}
