@@ -164,9 +164,7 @@ void                       ephy_web_view_get_security_level       (EphyWebView
                                                                    EphyWebViewSecurityLevel  *level,
                                                                    char                     **description);
 void                       ephy_web_view_show_page_certificate    (EphyWebView               *view);
-void                       ephy_web_view_show_print_preview       (EphyWebView               *view);
 void                       ephy_web_view_print                    (EphyWebView               *view);
-GSList *                   ephy_web_view_get_go_up_list           (EphyWebView               *view);
 void                       ephy_web_view_set_title                (EphyWebView               *view,
                                                                    const char                *view_title);
 const char *               ephy_web_view_get_title                (EphyWebView               *view);
