@@ -33,9 +33,7 @@
 #include "window-commands.h"
 #include "ephy-file-helpers.h"
 #include "ephy-debug.h"
-#include "ephy-stock-icons.h"
 #include "ephy-gui.h"
-#include "ephy-stock-icons.h"
 #include "ephy-search-entry.h"
 #include "ephy-session.h"
 #include "ephy-favicon-cache.h"
@@ -131,44 +129,44 @@ static const GtkActionEntry ephy_history_ui_entries [] = {
 	{ "PopupAction", NULL, "" },
 
 	/* File Menu */
-	{ "OpenInWindow", GTK_STOCK_OPEN, N_("Open in New _Window"), "<control>O",
+	{ "OpenInWindow", NULL, N_("Open in New _Window"), "<control>O",
 	  N_("Open the selected history link in a new window"),
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected history link in a new tab"),
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
-	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark…"), "<control>D",
+	{ "BookmarkLink", NULL, N_("Add _Bookmark…"), "<control>D",
 	  N_("Bookmark the selected history link"),
 	  G_CALLBACK (cmd_bookmark_link) },
-	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
+	{ "Close", NULL, N_("_Close"), "<control>W",
 	  N_("Close the history window"),
 	  G_CALLBACK (cmd_close) },
 
 	/* Edit Menu */
-	{ "Cut", GTK_STOCK_CUT, N_("Cu_t"), "<control>X",
+	{ "Cut", NULL, N_("Cu_t"), "<control>X",
 	  N_("Cut the selection"),
 	  G_CALLBACK (cmd_cut) },
-	{ "Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
+	{ "Copy", NULL, N_("_Copy"), "<control>C",
 	  N_("Copy the selection"),
 	  G_CALLBACK (cmd_copy) },
-	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), "<control>V",
+	{ "Paste", NULL, N_("_Paste"), "<control>V",
 	  N_("Paste the clipboard"),
 	  G_CALLBACK (cmd_paste) },
-	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), "<control>T",
+	{ "Delete", NULL, N_("_Delete"), "<control>T",
 	  N_("Delete the selected history link"),
 	  G_CALLBACK (cmd_delete) },
-	{ "SelectAll", GTK_STOCK_SELECT_ALL, N_("Select _All"), "<control>A",
+	{ "SelectAll", NULL, N_("Select _All"), "<control>A",
 	  N_("Select all history links or text"),
 	  G_CALLBACK (cmd_select_all) },
-	{ "Clear", GTK_STOCK_CLEAR, N_("Clear _History"), NULL,
+	{ "Clear", NULL, N_("Clear _History"), NULL,
 	  N_("Clear your browsing history"),
 	  G_CALLBACK (cmd_clear) },
 
 	/* Help Menu */
-	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	{ "HelpContents", NULL, N_("_Contents"), "F1",
 	  N_("Display history help"),
 	  G_CALLBACK (cmd_help_contents) },
-	{ "HelpAbout", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	{ "HelpAbout", NULL, N_("_About"), NULL,
 	  N_("Display credits for the web browser creators"),
 	  G_CALLBACK (window_cmd_help_about) },
 };
@@ -234,7 +232,6 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Clear History"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (confirmation_dialog_response_cb),
@@ -1096,7 +1093,6 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
 
 	gtk_window_set_title (GTK_WINDOW (editor), _("History"));
-	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_HISTORY);
 
 	g_signal_connect (editor, "delete_event",
 			  G_CALLBACK (delete_event_cb), NULL);
